.. _libdoc_graph_params_type:

=======================================================================
:mod:`aesara.graph.params_type` -- Wrapper class for :class:`Op` params
=======================================================================

---------
Reference
---------

.. automodule:: aesara.graph.params_type
   :platform: Unix, Windows
   :synopsis: Wrapper class for op params
   :members:
   :member-order: bysource
.. moduleauthor:: LISA
